@@ -42,7 +42,7 @@
 
 /* RCS version string for later identification using rcs ident {{{*/
 #ifndef lint
-static volatile const char *RCSid = "@(#) $Id: cfg.c,v 1.13 2004/04/29 11:12:57 mbr Exp $";
+static volatile const char *RCSid = "@(#) $Id: cfg.c,v 1.14 2004/08/18 13:57:32 mbr Exp $";
 #endif /* lint */
 /* }}} */
 
@@ -1355,9 +1355,9 @@ void print_usage(const char *prog) /* {{{ */
   printf(_("   -h, --help           display this help\n"));
   printf(_("   -d, --daemon         start in daemon mode\n"));
   printf(_("   -c, --config=FILE    read FILE as additional configuration file\n"));
-  printf(_("   -m, --mixer=STATE    use OSS software mixer [off]\n"));
+  printf(_("   -m, --mixer=STATE    use OSS software mixer [%s]\n"), DEFAULT_MIXER == STATE_ON ? CFG_MIXER_ON : CFG_MIXER_OFF);
 #ifdef HAVE_LIBXOSD
-  printf(_("   -o, --osd=STATE      show informations as on-screen display [on]\n"));
+  printf(_("   -o, --osd=STATE      show informations as on-screen display [%s]\n"), DEFAULT_OSD == STATE_ON ? CFG_OSD_ON : CFG_OSD_OFF);
 #endif /* HAVE_LIBXOSD */
   printf(_("   -p, --poll=DELAY     set delay between polls in microseconds [%d]\n"), DEFAULT_POLLTIME);
   printf(_("   -t, --thinkpad=CMD   string with command and options that should be executed\n"));
@@ -1369,9 +1369,9 @@ void print_usage(const char *prog) /* {{{ */
   printf(_("   -C, --callback=CMD   string with command that should be executed for each\n"));
   printf(_("                        pressed button. It is called with pressed button as\n"));
   printf(_("                        first argument and new state as second [none]\n"));
-  printf(_("   -A, --apm=STATE      poll /proc/apm for apm information [off]\n"));
-  printf(_("   -P, --powermgt=STATE display of power management messages [auto]\n"));
-  printf(_("   -x, --xevents=STATE  grab X11 events of special keys [on]\n"));
+  printf(_("   -A, --apm=STATE      poll /proc/apm for apm information [%s]\n"), DEFAULT_APM == STATE_ON ? CFG_APM_ON : CFG_APM_OFF);
+  printf(_("   -P, --powermgt=STATE display of power management messages [%s]\n"), DEFAULT_POWERMGT == STATE_ON ? CFG_POWERMGT_ON : DEFAULT_POWERMGT == STATE_OFF ? CFG_POWERMGT_OFF : CFG_POWERMGT_AUTO);
+  printf(_("   -x, --xevents=STATE  grab X11 events of special keys [%s]\n"), DEFAULT_XEVENTS == STATE_ON ? CFG_XEVENTS_ON : CFG_XEVENTS_OFF);
   printf(_("   -v, --verbose        print information about pressed keys\n"));
   return;
 } /* }}} */
