@@ -52,7 +52,7 @@
 
 /* RCS version string for later identification using rcs ident {{{ */
 #ifndef lint
-static volatile const char *RCSid = "@(#) $Id: tpb.c,v 1.23 2004/05/18 11:21:18 mbr Exp $";
+static volatile const char *RCSid = "@(#) $Id: tpb.c,v 1.29 2004/08/22 13:45:11 mbr Exp $";
 #endif /* lint */
 /* }}} */
 
@@ -185,8 +185,12 @@ int main(int argc, char **argv) /* {{{ */
   }
 
   while(0 == 0) {
+    /* sleep for polltime */
+    usleep(cfg.polltime);
+
     /* save last state and get new one */
     memcpy(&last_thinkpad_state, &thinkpad_state, sizeof(t_thinkpad_state));
+
     if(get_nvram_state(&thinkpad_state) != 0) {
       _exit(1);
     }
@@ -198,7 +202,11 @@ int main(int argc, char **argv) /* {{{ */
       xgrabkey(&thinkpad_state, display);
     }
 #endif /* HAVE_LIBX11 */
-
+    
+    /* check if anything changed */
+    if(memcmp(&last_thinkpad_state, &thinkpad_state, sizeof(t_thinkpad_state)) == 0) {
+      continue;
+    }
 
     /* determine the state of the Thinkpad button  {{{ */
     if(thinkpad_state.thinkpad_toggle != last_thinkpad_state.thinkpad_toggle &&
@@ -703,9 +711,6 @@ int main(int argc, char **argv) /* {{{ */
       }
 #endif /* HAVE_LIBXOSD */
     } /* }}} */
-
-    /* sleep for polltime */
-    usleep(cfg.polltime);
   }
 
   _exit(0); /* never reached */
@@ -726,7 +731,7 @@ void init_i18n(void) /* {{{ */
 /* when called, the application becomes a daemon */
 void daemonize(void) /* {{{ */
 {
-  int filedes;
+  int fdsc, fdsc_max;
 
   /* code inspired by comp.unix.programmer FAQ */
   switch (fork())
@@ -765,9 +770,9 @@ void daemonize(void) /* {{{ */
   /* change to root directory */
   chdir("/");
 
-  /* close all filedescriptors */
-  for(filedes = 0 ; filedes < sysconf(_SC_OPEN_MAX) ; filedes++) {
-    close(filedes);
+  /* close all file descriptors */
+  for (fdsc = 0, fdsc_max = sysconf(_SC_OPEN_MAX); fdsc < fdsc_max; fdsc++) {
+    close(fdsc);
   }
 
   /* open /dev/null as file descriptor 0 */
@@ -967,29 +972,44 @@ Display *init_xgrabkey(void) /* {{{ */
 /* get the current state from the nvram */
 int get_nvram_state(t_thinkpad_state *thinkpad_state) /* {{{ */
 {
-  int  fdsc;
+  static int fdsc = -1; /* -1 -> file not opened */
   unsigned char buffer[114];
+  struct {
+    int pos;
+    int len;
+  } pos_len[] = {
+    { 0x39, 0x01 },
+    { 0x56, 0x04 },
+    { 0x5e, 0x01 },
+    { 0x60, 0x01 },
+    { 0x00, 0x00 } /* end */
+  };
+  int pos_len_idx = 0;
 
   /* open nvram for reading */
-  /* must use open/close because seek is not supported by nvram */
-  if((fdsc=open(cfg.nvram, O_RDONLY|O_NONBLOCK)) == -1) {
-    fprintf(stderr, _("Unable to open device %s: "), cfg.nvram);
-    perror(NULL);
-    return -1;
+  if(fdsc == -1) { /* if not already opened, open nvram */
+    if((fdsc=open(cfg.nvram, O_RDONLY|O_NONBLOCK)) == -1) {
+      fprintf(stderr, _("Unable to open device %s: "), cfg.nvram);
+      perror(NULL);
+      return -1;
+    }
   }
 
-  /* read nvram */
-  if(read(fdsc, buffer, sizeof(buffer)) != sizeof(buffer)) {
-    fprintf(stderr, _("Unable to read from device %s: "), cfg.nvram);
-    perror(NULL);
-    return -1;
-  }
+  /* Read only the interesting bytes from nvram to reduce the CPU consupmtion of tpb */
+  /* The kernel nvram driver reads byte-by-byte from nvram, so just reading interesting bytes reduces the amount of inb() calls */
+  while (pos_len[pos_len_idx].pos != 0x0) {
+    if(lseek(fdsc, pos_len[pos_len_idx].pos, SEEK_SET) != pos_len[pos_len_idx].pos ) {
+      fprintf(stderr, _("Unable to seek in device %s: "), cfg.nvram);
+      perror(NULL);
+      return -1;
+    }
+    if(read(fdsc, buffer+pos_len[pos_len_idx].pos, pos_len[pos_len_idx].len) != pos_len[pos_len_idx].len) {
 
-  /* close nvram device */
-  if(close(fdsc) == -1) {
-    fprintf(stderr, _("Unable to close device %s: "), cfg.nvram);
-    perror(NULL);
-    return -1;
+      fprintf(stderr, _("Unable to read from device %s: "), cfg.nvram);
+      perror(NULL);
+      return -1;
+    }
+    pos_len_idx++;
   }
 
   thinkpad_state->thinkpad_toggle   = (thinkpad_state->thinkpad_toggle   & ~0x01) | (( buffer[0x57] & 0x08) >> 3);
@@ -1018,7 +1038,7 @@ int get_nvram_state(t_thinkpad_state *thinkpad_state) /* {{{ */
 int get_apm_state(t_thinkpad_state *thinkpad_state) /* {{{ */
 {
   unsigned int i;
-  int proc_apm;
+  static int fdsc = -1; /* -1 -> file not opened */
   char buffer[38];
   char *tokens[9];
 
@@ -1054,26 +1074,30 @@ int get_apm_state(t_thinkpad_state *thinkpad_state) /* {{{ */
    *    0xff: Unknown                                            
    * 6) Remaining battery life (percentage of charge):           
    *    0-100: valid                                             
-  *    -1: Unknown                                              
-    * 7) Remaining battery life (time units):                     
-    *    Number of remaining minutes or seconds                   
-    *    -1: Unknown                                              
-    * 8) min = minutes; sec = seconds */                          
+   *    -1: Unknown                                              
+   * 7) Remaining battery life (time units):                     
+   *    Number of remaining minutes or seconds                   
+   *    -1: Unknown                                              
+   * 8) min = minutes; sec = seconds
+   */
 
-    /* open /proc/apm */
-    if((proc_apm = open("/proc/apm", O_RDONLY)) == -1) {
-      return -1;
-    }
+   /* open /proc/apm */
+   if(fdsc == -1) { /* if not already opened, open apm */
+     if((fdsc = open("/proc/apm", O_RDONLY)) == -1) {
+       return -1;
+     }
+   }
+
+   /* seek to the beginning of the file */
+   if(lseek(fdsc, 0, SEEK_SET) != 0 ) {
+     return -1;
+   }
 
   /* read apm state */
-  if(read(proc_apm, buffer, sizeof(buffer)) != sizeof(buffer)) {
-    close(proc_apm);
+  if(read(fdsc, buffer, sizeof(buffer)) != sizeof(buffer)) {
     return -1;
   }
 
-  /* no need to keep file open */
-  close(proc_apm);
-
   /* tokenize the apm string */
   tokens[0] = strtok(buffer, " ");
   for(i = 1 ; i < sizeof(tokens)/sizeof(char*) ; i++) {
@@ -1103,7 +1127,7 @@ int xgrabkey(t_thinkpad_state *thinkpad_state, Display *display) /* {{{ */
   while(XPending(display) > 0) {
     XNextEvent(display, &event);
 
-    if (event.xkey.type == KeyPress) { // needed, because KeyReleases are also received, even if XSelectInput only specifies KeyPressMask!!
+    if (event.xkey.type == KeyPress) { /* needed, because KeyReleases are also received, even if XSelectInput only specifies KeyPressMask!! */
       switch(event.xkey.keycode) {
 	case KEYCODE_HOME:
 	  thinkpad_state->home_toggle ^= 0x02;
@@ -1163,6 +1187,7 @@ int fork_app(char * cmd) /* {{{ */
   int argc;
   enum mode_t mode;
   char quote_char;
+  int fdsc, fdsc_max;
 
   switch(fork()) {
     case -1:
@@ -1178,6 +1203,11 @@ int fork_app(char * cmd) /* {{{ */
       cmd_cpy = strdup(cmd);
       cmd_len = strlen(cmd_cpy);
 
+      /* close ALL file descriptors except stdin, stdout and stderr */
+      for (fdsc = 3, fdsc_max = sysconf(_SC_OPEN_MAX); fdsc < fdsc_max; fdsc++) {
+        close(fdsc);
+      }
+
       /* generate an array of cmd_cpy string */
       while (ptr < cmd_len) {
 	switch (mode) {
