@@ -1,5 +1,5 @@
 /* tpb - program to use the IBM ThinkPad(tm) special keys
- * Copyright (C) 2002,2003 Markus Braun <markus.braun@krawel.de>
+ * Copyright (C) 2002-2004 Markus Braun <markus.braun@krawel.de>
  *
  * This file is part of tpb.
  *
@@ -30,6 +30,7 @@
 
 #define MAX_VOLUME 100
 #define CALLBACK_CMD_LENGTH 256
+#define CALLBACK_CMD_ARGS 30
 
 #define KEYCODE_HOME 178
 #define KEYCODE_SEARCH 229
@@ -50,6 +51,7 @@ typedef struct {
   unsigned int home_toggle;         /* Home button */
   unsigned int search_toggle;       /* Search button */
   unsigned int mail_toggle;         /* Mail button */
+  unsigned int wireless_toggle;     /* Wireless button */
   unsigned int favorites_toggle;    /* Favorites button */
   unsigned int reload_toggle;       /* Reload button */
   unsigned int abort_toggle;        /* Abort button */
